@@ -3,6 +3,9 @@
 # email:yuyc@ishangqi.com
 # date:2022/2/17 2:45 下午
 # Copyright (C) 2022 The lesscode Team
+import psycopg2
+from dbutils.pooled_db import PooledDB
+
 from lesscode.db.base_connection_pool import BaseConnectionPool
 from aiopg import create_pool
 
@@ -27,3 +30,8 @@ class PostgresqlPool(BaseConnectionPool):
             return pool
         else:
             raise NotImplementedError
+
+    def sync_create_pool(self):
+        pool = PooledDB(psycopg2, 5, host=self.conn_info.host, port=self.conn_info.port, user=self.conn_info.user,
+                        password=self.conn_info.password, database=self.conn_info.db_name)
+        return pool
